TinySecondaryMap

Struct TinySecondaryMap 

pub struct TinySecondaryMap<K: Key, V> { /* private fields */ }

Implementations

Source

impl<K: Key, V> TinySecondaryMap<K, V>

pub unsafe fn iter_many_unchecked_mut<'a, I>( &'a mut self, keys: I, ) -> IterManyMut<'a, K, V, I::IntoIter>
where I: IntoIterator<Item = K>, <I as IntoIterator>::IntoIter: 'a,

Returns an iterator of mutable references to the values corresponding to the keys.

Safety

The caller must ensure that the keys are valid and unique, otherwise the returned references will UB.

Source

impl<K: Key, V> TinySecondaryMap<K, V>

pub fn new() -> Self

Construct a new, empty TinySecondaryMap.

pub fn with_capacity(capacity: usize) -> Self

Creates an emtpy TinySecondaryMap with the given capacity.

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn insert(&mut self, key: K, value: V) -> Option<V>

Inserts or replaces a value into the secondary map at the given key. Returns None if the key was not present, otherwise returns the previous value.

pub fn extend(&mut self, values: impl IntoIterator<Item = (K, V)>)

pub fn contains_key(&self, key: K) -> bool

pub fn get(&self, key: K) -> Option<&V>

Returns a reference to the value corresponding to the key.

pub fn get_mut(&mut self, key: K) -> Option<&mut V>

Returns a mutable reference to the value corresponding to the key.

pub fn first_key(&self) -> Option<K>

Returns the first non-empty key in the map.

pub fn iter(&self) -> Iter<'_, K, V>

Returns an iterator over the (K, V) entries in the map.

pub fn iter_mut(&mut self) -> IterMut<'_, K, V>

pub fn keys(&self) -> impl Iterator<Item = K> + '_

Returns an iterator over the keys in the map.

pub fn into_keys(self) -> Vec<K>

Turns the map into a vector of the keys in the map.

pub fn values(&self) -> ValuesIter<'_, V>

Returns an iterator over the values in the map, ordered by key.