pub struct TinySecondaryMap<K: Key, V> { /* private fields */ }Implementations
Sourceimpl<K: Key, V> TinySecondaryMap<K, V>
impl<K: Key, V> TinySecondaryMap<K, V>
Sourcepub unsafe fn iter_many_unchecked_mut<'a, I>(
&'a mut self,
keys: I,
) -> IterManyMut<'a, K, V, I::IntoIter> ⓘ
pub unsafe fn iter_many_unchecked_mut<'a, I>( &'a mut self, keys: I, ) -> IterManyMut<'a, K, V, I::IntoIter> ⓘ
Returns an iterator of mutable references to the values corresponding to the keys.
Safety
The caller must ensure that the keys are valid and unique, otherwise the returned references will UB.
Sourceimpl<K: Key, V> TinySecondaryMap<K, V>
impl<K: Key, V> TinySecondaryMap<K, V>
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct a new, empty TinySecondaryMap.
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Creates an emtpy TinySecondaryMap with the given capacity.
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
Sourcepub fn insert(&mut self, key: K, value: V) -> Option<V>
pub fn insert(&mut self, key: K, value: V) -> Option<V>
Inserts or replaces a value into the secondary map at the given key. Returns None if
the key was not present, otherwise returns the previous value.
pub fn extend(&mut self, values: impl IntoIterator<Item = (K, V)>)
pub fn contains_key(&self, key: K) -> bool
Sourcepub fn get(&self, key: K) -> Option<&V>
pub fn get(&self, key: K) -> Option<&V>
Returns a reference to the value corresponding to the key.
Sourcepub fn get_mut(&mut self, key: K) -> Option<&mut V>
pub fn get_mut(&mut self, key: K) -> Option<&mut V>
Returns a mutable reference to the value corresponding to the key.
pub fn iter_mut(&mut self) -> IterMut<'_, K, V> ⓘ
Sourcepub fn keys(&self) -> impl Iterator<Item = K> + '_
pub fn keys(&self) -> impl Iterator<Item = K> + '_
Returns an iterator over the keys in the map.
Sourcepub fn values(&self) -> ValuesIter<'_, V> ⓘ
pub fn values(&self) -> ValuesIter<'_, V> ⓘ
Returns an iterator over the values in the map, ordered by key.